Jupyter Enhancement Proposals
=============================

Submitting an Enhancement Proposal
----------------------------------
While using the Notebook, you might discover opportunities for growth and ideas
for useful new features. If so, feel free to submit an enhancement proposal.
The process for submitting enhancements is as follows:

1. Identify the scope of the enhancement. Is it a change that affects only on
   part of the codebase? Is the enhancement, to the best of your knowledge, fairly
   trivial to implement? If the scope of the enhancement is small, it should be
   be submitted as an issue in the project's repository. If the scope of your
   enhancement is large, it should be submitted to the official `Jupyter
   Enhancement Proposals repository <https://GitHub.com/jupyter/enhancement-proposals>`_.

2. Prepare a brief write-up of the problem that your enhancement will address.

3. Prepare a brief write-up of the proposed enhancement itself.

4. If the scope of your enhancement (as defined in step 1) is large, then
   prepare a detailed write-up of how your enhancement can be potentially implemented.

5. Identify a brief list of the pros and cons associated with implementing the
   enhancement that you propose.

6. Identify the individuals who might be interested in implementing the enhancement.

7. Depending on the scope of your enhancement, submit it either as an issue to
   the appropriate repository or as a Jupyter Enhancement Proposal.
